@@ -29,4 +29,4 @@ class TaxiOpsLogger(logging.Logger):
 
     def __init__(self):
         logging.Logger.__init__(self, 'TaxiOps', 'DEBUG')
-        self.addHandler(TaxiOpsLogger.TaxiOpsLogFileHandler('logs/TaxiOps.log'))
+        self.addHandler(TaxiOpsLogger.TaxiOpsLogStreamHandler())
